==> haskell-http-client-0.5.13.1-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.13.1
id: http-client-0.5.13.1-5bWLsxn43Qn5Sy0HIJpRM7
key: http-client-0.5.13.1-5bWLsxn43Qn5Sy0HIJpRM7
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: 6cc34132fb382d5ab0ee66c735e85dcb
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-client-0.5.13.1
hs-libraries: HShttp-client-0.5.13.1-5bWLsxn43Qn5Sy0HIJpRM7
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    http-types-0.12.1-GCbCLe1aYsqFpIOyGb3viY
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 time-1.8.0.2
    network-2.7.0.2-JHUM0ViK2K4GlR2R7mbtvw
    streaming-commons-0.2.1.0-GpfayW1EIyU4V4ckdsXq2w
    containers-0.5.11.0 transformers-0.5.5.0 deepseq-1.4.3.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf array-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV filepath-1.4.2
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4 ghc-prim-0.5.2.0
    stm-2.4.5.0 network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             http-types-0.12.1-GCbCLe1aYsqFpIOyGb3viY=6e90bd4bb209b22c846532a1f50e8ee3
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             network-2.7.0.2-JHUM0ViK2K4GlR2R7mbtvw=812892e9709ff9741ac132eadbf8f11c
             streaming-commons-0.2.1.0-GpfayW1EIyU4V4ckdsXq2w=12571a2985ccb41c4f773b6504cd3490
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=1f2d3d0537de744febdcb254f1bfc8b9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-client-0.5.13.1-11-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-http-client.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-client
version: 0.5.13.1
id: http-client-0.5.13.1-3toxJfBE59PAIZbOjn1vZq
key: http-client-0.5.13.1-3toxJfBE59PAIZbOjn1vZq
license: MIT
maintainer: michael@snoyman.com
author: Michael Snoyman
homepage: https://github.com/snoyberg/http-client
synopsis: An HTTP client engine
description:
    Hackage documentation generation is not reliable. For up to date documentation, please see: <http://www.stackage.org/package/http-client>.
category: Network
abi: ebf8ac947014b4c7473903f8a577adce
exposed: True
exposed-modules:
    Network.HTTP.Client Network.HTTP.Client.Internal
    Network.HTTP.Client.MultipartFormData
hidden-modules: Network.HTTP.Client.Body
                Network.HTTP.Client.Connection Network.HTTP.Client.Cookies
                Network.HTTP.Client.Core Network.HTTP.Client.Headers
                Network.HTTP.Client.Manager Network.HTTP.Client.Request
                Network.HTTP.Client.Response Network.HTTP.Client.Types
                Network.HTTP.Client.Util Network.HTTP.Proxy
                Network.PublicSuffixList.Lookup Network.PublicSuffixList.Types
                Network.PublicSuffixList.Serialize
                Network.PublicSuffixList.DataStructure Data.KeyedPool
import-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
library-dirs: /usr/lib/ghc-8.4.3/site-local/http-client-0.5.13.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/http-client-0.5.13.1
hs-libraries: HShttp-client-0.5.13.1-3toxJfBE59PAIZbOjn1vZq
depends:
    base-4.11.1.0 bytestring-0.10.8.2 text-1.2.3.0
    http-types-0.12.1-86SMkuMxdGmiSnGNxpMRm
    blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028 time-1.8.0.2
    network-2.7.0.2-2uNz8SJYvMr2FoPImv9yYz
    streaming-commons-0.2.1.0-Dsn8X01z8OiKrfnfaKdXVz
    containers-0.5.11.0 transformers-0.5.5.0 deepseq-1.4.3.0
    case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra
    memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk
    cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ
    exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf array-0.5.2.0
    random-1.1-9LLJAJa4iQFLJiLXBOBXBV filepath-1.4.2
    mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4 ghc-prim-0.5.2.0
    stm-2.4.5.0 network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             bytestring-0.10.8.2=9faa89cf4769cbd12751f8644ca9e618
             text-1.2.3.0=9752fd647a108be49a4cb0c2a4456f2b
             http-types-0.12.1-86SMkuMxdGmiSnGNxpMRm=78d489696f728b72c10468a4eac9f283
             blaze-builder-0.4.1.0-Gz7BwSYlOrTDOutVN7e028=f952a1ec5abae3e4435518edbfd82e4e
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             network-2.7.0.2-2uNz8SJYvMr2FoPImv9yYz=593cfbdab1e8a8c0dc553b5ae47d8025
             streaming-commons-0.2.1.0-Dsn8X01z8OiKrfnfaKdXVz=29ddb33e08a0de18a7fbf61e7b671867
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             transformers-0.5.5.0=4f41484af13f560f1d83ed79e1be4572
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             case-insensitive-1.2.0.11-GjimmYhRn324HWbQThQUra=0a5994e39a32f328ff4f350b25844411
             memory-0.14.16-FrHKJ6EcQ5I95PPEhrgDqk=a0627d5d7afb3952e7ea8a317c372f9d
             cookie-0.4.4-JPTjqtKlVKyLfZoDZSF6OJ=98943a44942d0f9eb24e49aaa7774a37
             exceptions-0.10.0-391qhPSiPEU3NJgxhfdaPf=7910067871295cb7f4f6699a852863a6
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             mime-types-0.1.0.8-9tF87HO5ShrGIShG8eldW4=1f2d3d0537de744febdcb254f1bfc8b9
             ghc-prim-0.5.2.0=387aa7e78e4e6c49e51798e4d6763c3f
             stm-2.4.5.0=4e743cb5a370ac3fbade528432951c3f
             network-uri-2.6.1.0-AstEwZoXrlUJQq4VkxaVo9=4ea8f0efa7a1ade0af4e9ce0cffcff8c
haddock-interfaces: /usr/share/doc/haskell-http-client/html/http-client.haddock
haddock-html: /usr/share/doc/haskell-http-client/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
